@@ -10,15 +10,11 @@
 #   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-#   Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+#   Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Template.pm,v 2.87 2006/05/30 17:01:26 abw Exp $
-#
 #========================================================================
 
 package Template;
@@ -34,7 +30,7 @@ use Template::Service;
 use File::Basename;
 use File::Path;
 
-our $VERSION = '2.18';
+our $VERSION = '2.20';
 our $ERROR   = '';
 our $DEBUG   = 0;
 our $BINMODE = 0 unless defined $BINMODE;
@@ -72,7 +68,7 @@ sub process {
         unless (ref $outstream) {
             my $outpath = $self->{ OUTPUT_PATH };
             $outstream = "$outpath/$outstream" if $outpath;
-        }	
+        }   
 
         # send processed template to output stream, checking for error
         return ($self->error($error))
@@ -190,7 +186,7 @@ sub _output {
         elsif (open(FP, ">$where")) { 
             # binmode option can be 1 or a specific layer, e.g. :utf8
             my $bm = $options->{ binmode  };
-            if ($bm && +$bm == 1) { 
+            if ($bm && $bm eq 1) { 
                 binmode FP;
             }
             elsif ($bm){ 
@@ -216,53 +212,41 @@ sub _output {
 
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template - Front-end module to the Template Toolkit
 
 =head1 SYNOPSIS 
 
-  use Template;
-
-  # some useful options (see below for full list)
-  my $config = {
-      INCLUDE_PATH => '/search/path',  # or list ref
-      INTERPOLATE  => 1,               # expand "$var" in plain text
-      POST_CHOMP   => 1,               # cleanup whitespace 
-      PRE_PROCESS  => 'header',        # prefix each template
-      EVAL_PERL    => 1,               # evaluate Perl code blocks
-  };
-
-  # create Template object
-  my $template = Template->new($config);
-
-  # define template variables for replacement
-  my $vars = {
-      var1  => $value,
-      var2  => \%hash,
-      var3  => \@list,
-      var4  => \&code,
-      var5  => $object,
-  };
-
-  # specify input filename, or file handle, text reference, etc.
-  my $input = 'myfile.html';
-
-  # process input template, substituting variables
-  $template->process($input, $vars)
-      || die $template->error();
+    use Template;
+    
+    # some useful options (see below for full list)
+    my $config = {
+        INCLUDE_PATH => '/search/path',  # or list ref
+        INTERPOLATE  => 1,               # expand "$var" in plain text
+        POST_CHOMP   => 1,               # cleanup whitespace 
+        PRE_PROCESS  => 'header',        # prefix each template
+        EVAL_PERL    => 1,               # evaluate Perl code blocks
+    };
+    
+    # create Template object
+    my $template = Template->new($config);
+    
+    # define template variables for replacement
+    my $vars = {
+        var1  => $value,
+        var2  => \%hash,
+        var3  => \@list,
+        var4  => \&code,
+        var5  => $object,
+    };
+    
+    # specify input filename, or file handle, text reference, etc.
+    my $input = 'myfile.html';
+    
+    # process input template, substituting variables
+    $template->process($input, $vars)
+        || die $template->error();
 
 =head1 DESCRIPTION
 
@@ -278,20 +262,20 @@ as an introductory guide to using the Template Toolkit.
 
 =head2 new(\%config)
 
-The new() constructor method (implemented by the Template::Base base
-class) instantiates a new Template object.  A reference to a hash
-array of configuration items may be passed as a parameter.
+The C<new()> constructor method (implemented by the
+L<Template::Base|Template::Base#new()> base class) instantiates a new
+C<Template> object. A reference to a hash array of configuration items may be
+passed as a parameter.
 
     my $tt = Template->new({
-    	INCLUDE_PATH => '/usr/local/templates',
-	    EVAL_PERL    => 1,
+        INCLUDE_PATH => '/usr/local/templates',
+        EVAL_PERL    => 1,
     }) || die $Template::ERROR, "\n";
 
-A reference to a new Template object is returned, or undef on error.
-In the latter case, the error message can be retrieved by calling
-error() as a class method (e.g. C<Template-E<gt>error()>) or by
-examining the $ERROR package variable directly
-(e.g. C<$Template::ERROR>).
+A reference to a new C<Template> object is returned, or undef on error. In the
+latter case, the error message can be retrieved by calling L<error()> as a
+class method or by examining the C<$Template::ERROR> package variable
+directly.
 
     my $tt = Template->new(\%config)
         || die Template->error(), "\n";
@@ -304,49 +288,47 @@ of items instead of a hash array reference.  These are automatically
 folded into a hash array by the constructor.
 
     my $tt = Template->new(INCLUDE_PATH => '/tmp', POST_CHOMP => 1)
-	|| die $Template::ERROR, "\n";
+        || die $Template::ERROR, "\n";
 
 =head2 process($template, \%vars, $output, %options)
 
-The process() method is called to process a template.  The first
-parameter indicates the input template as one of: a filename relative
-to INCLUDE_PATH, if defined; a reference to a text string containing
-the template text; or a file handle reference (e.g. IO::Handle or
-sub-class) or GLOB (e.g. \*STDIN), from which the template can be
-read.  A reference to a hash array may be passed as the second
-parameter, containing definitions of template variables.
-
-    $text = "[% INCLUDE header %]\nHello world!\n[% INCLUDE footer %]";
+The C<process()> method is called to process a template. The first parameter
+indicates the input template as one of: a filename relative to
+C<INCLUDE_PATH>, if defined; a reference to a text string containing the
+template text; or a file handle reference (e.g. C<IO::Handle> or sub-class) or
+C<GLOB> (e.g. C<\*STDIN>), from which the template can be read. A reference to
+a hash array may be passed as the second parameter, containing definitions of
+template variables.
 
     # filename
     $tt->process('welcome.tt2')
         || die $tt->error(), "\n";
 
     # text reference
+    $text = "[% INCLUDE header %]\nHello world!\n[% INCLUDE footer %]";
     $tt->process(\$text)
         || die $tt->error(), "\n";
 
-    # GLOB
+    # file handle (GLOB)
     $tt->process(\*DATA)
         || die $tt->error(), "\n";
-
+    
     __END__
     [% INCLUDE header %]
     This is a template defined in the __END__ section which is 
     accessible via the DATA "file handle".
     [% INCLUDE footer %]
 
-By default, the processed template output is printed to STDOUT.  The
-process() method then returns 1 to indicate success.  A third
-parameter may be passed to the process() method to specify a different
-output location.  This value may be one of: a plain string indicating
-a filename which will be opened (relative to OUTPUT_PATH, if defined)
-and the output written to; a file GLOB opened ready for output; a
-reference to a scalar (e.g. a text string) to which output/error is
-appended; a reference to a subroutine which is called, passing the
-output as a parameter; or any object reference which implements a
-'print' method (e.g. IO::Handle, Apache::Request, etc.) which will 
-be called, passing the generated output as a parameter.
+By default, the processed template output is printed to C<STDOUT>. The
+C<process()> method then returns C<1> to indicate success. A third parameter
+may be passed to the C<process()> method to specify a different output location.
+This value may be one of: a plain string indicating a filename which will be
+opened (relative to C<OUTPUT_PATH>, if defined) and the output written to; a file
+GLOB opened ready for output; a reference to a scalar (e.g. a text string) to
+which output/error is appended; a reference to a subroutine which is called,
+passing the output as a parameter; or any object reference which implements a
+C<print()> method (e.g. C<IO::Handle>, C<Apache::Request>, etc.) which will be called,
+passing the generated output as a parameter.
 
 Examples:
 
@@ -356,8 +338,8 @@ Examples:
 
     # reference to output subroutine
     sub myout {
-    	my $output = shift;
-	    ...
+        my $output = shift;
+        ...
     }
     $tt->process('welcome.tt2', $vars, \&myout)
         || die $tt->error(), "\n";
@@ -372,66 +354,65 @@ Examples:
 In an Apache/mod_perl handler:
 
     sub handler {
-	my $req = shift;
-
-        ...
-
-	# direct output to Apache::Request via $req->print($output)
-	$tt->process($file, $vars, $req) || do {
-	    $req->log_reason($tt->error());
-	    return SERVER_ERROR;
-	};
-
-	return OK;
+        my $req = shift;
+        
+        # ...your code here...
+        
+        # direct output to Apache::Request via $req->print($output)
+        $tt->process($file, $vars, $req) || do {
+            $req->log_reason($tt->error());
+            return SERVER_ERROR;
+        };
+        return OK;
     }
 
 After the optional third output argument can come an optional
-reference to a hash or a list of (name, value) pairs providing further
+reference to a hash or a list of C<(name, value)> pairs providing further
 options for the output.  The only option currently supported is
-"binmode" which, when set to any true value will ensure that files
+C<binmode> which, when set to any true value will ensure that files
 created (but not any existing file handles passed) will be set to
 binary mode.
 
     # either: hash reference of options
     $tt->process($infile, $vars, $outfile, { binmode => 1 })
         || die $tt->error(), "\n";
-
+    
     # or: list of name, value pairs
     $tt->process($infile, $vars, $outfile, binmode => 1)
         || die $tt->error(), "\n";
 
-Alternately, the binmode argument can specify a particular IO layer such 
-as ":utf8".
+Alternately, the C<binmode> argument can specify a particular IO layer such 
+as C<:utf8>.
 
     $tt->process($infile, $vars, $outfile, binmode => ':utf8')
         || die $tt->error(), "\n";
 
-The OUTPUT configuration item can be used to specify a default output 
-location other than \*STDOUT.  The OUTPUT_PATH specifies a directory
+The C<OUTPUT> configuration item can be used to specify a default output 
+location other than C<\*STDOUT>.  The C<OUTPUT_PATH> specifies a directory
 which should be prefixed to all output locations specified as filenames.
 
     my $tt = Template->new({
-    	OUTPUT      => sub { ... },       # default
-	    OUTPUT_PATH => '/tmp',
-	...
+        OUTPUT      => sub { ... },       # default
+        OUTPUT_PATH => '/tmp',
+    ...
     }) || die Template->error(), "\n";
-
+    
     # use default OUTPUT (sub is called)
     $tt->process('welcome.tt2', $vars)
         || die $tt->error(), "\n";
-
+        
     # write file to '/tmp/welcome.html'
     $tt->process('welcome.tt2', $vars, 'welcome.html')
         || die $tt->error(), "\n";
 
-The process() method returns 1 on success or undef on error.  The error
-message generated in the latter case can be retrieved by calling the
-error() method.  See also L<CONFIGURATION SUMMARY> which describes how
-error handling may be further customised.
+The C<process()> method returns C<1> on success or C<undef> on error. The
+error message generated in the latter case can be retrieved by calling the
+L<error()> method. See also L<CONFIGURATION SUMMARY> which describes how error
+handling may be further customised.
 
 =head2 error()
 
-When called as a class method, it returns the value of the $ERROR package
+When called as a class method, it returns the value of the C<$ERROR> package
 variable.  Thus, the following are equivalent.
 
     my $tt = Template->new()
@@ -441,40 +422,41 @@ variable.  Thus, the following are equivalent.
         || die $Template::ERROR, "\n";
 
 When called as an object method, it returns the value of the internal
-_ERROR variable, as set by an error condition in a previous call to
+C<_ERROR> variable, as set by an error condition in a previous call to
 process().
 
     $tt->process('welcome.tt2')
         || die $tt->error(), "\n";
 
 Errors are represented in the Template Toolkit by objects of the
-Template::Exception class.  If the process() method returns a false
-value then the error() method can be called to return an object of
-this class.  The type() and info() methods can called on the object to
-retrieve the error type and information string, respectively.  The
-as_string() method can be called to return a string of the form "$type
-- $info".  This method is also overloaded onto the stringification
-operator allowing the object reference itself to be printed to return
-the formatted error string.
+L<Template::Exception> class. If the L<process()> method returns a false value
+then the C<error()> method can be called to return an object of this class.
+The L<type()|Template::Exception#type()> and
+L<info()|Template::Exception#info()> methods can called on the object to
+retrieve the error type and information string, respectively. The 
+L<as_string()|Template::Exception#as_string()>
+method can be called to return a string of the form C<$type - $info>. This
+method is also overloaded onto the stringification operator allowing the
+object reference itself to be printed to return the formatted error string.
 
     $tt->process('somefile') || do {
-    	my $error = $tt->error();
-	    print "error type: ", $error->type(), "\n";
-    	print "error info: ", $error->info(), "\n";
-	    print $error, "\n";
+        my $error = $tt->error();
+        print "error type: ", $error->type(), "\n";
+        print "error info: ", $error->info(), "\n";
+        print $error, "\n";
     };
 
 =head2 service()
 
-The Template module delegates most of the effort of processing templates
-to an underlying Template::Service object.  This method returns a reference
+The C<Template> module delegates most of the effort of processing templates
+to an underlying L<Template::Service> object.  This method returns a reference
 to that object.
 
 =head2 context()
 
-The Template::Service module uses a core Template::Context object for
+The L<Template::Service> module uses a core L<Template::Context> object for
 runtime processing of templates.  This method returns a reference to 
-that object and is equivalent to $template-E<gt>service-E<gt>context();
+that object and is equivalent to C<< $template-E<gt>service-E<gt>context() >>.
 
 =head1 CONFIGURATION SUMMARY
 
@@ -483,224 +465,188 @@ configuration option.  See L<Template::Manual::Config> for full details.
 
 =head2 Template Style and Parsing Options
 
-=over 4
+=head3 START_TAG, END_TAG
 
-=item START_TAG, END_TAG
+Define tokens that indicate start and end of directives 
+(default: 'C<[%>' and 'C<%]>').
 
-Define tokens that indicate start and end of directives (default: '[%' and 
-'%]').
+=head3 TAG_STYLE
 
-=item TAG_STYLE
+Set C<START_TAG> and C<END_TAG> according to a pre-defined style (default:
+'C<template>', as above).
 
-Set START_TAG and END_TAG according to a pre-defined style (default: 
-'template', as above).
+=head3 PRE_CHOMP, POST_CHOMP
 
-=item PRE_CHOMP, POST_CHOMP
+Removes whitespace before/after directives (default: 0/0).
 
-Remove whitespace before/after directives (default: 0/0).
-
-=item TRIM
+=head3 TRIM
 
 Remove leading and trailing whitespace from template output (default: 0).
 
-=item INTERPOLATE
+=head3 INTERPOLATE
 
-Interpolate variables embedded like $this or ${this} (default: 0).
+Interpolate variables embedded like C<$this> or C<${this}> (default: 0).
 
-=item ANYCASE
+=head3 ANYCASE
 
 Allow directive keywords in lower case (default: 0 - UPPER only).
 
-=back
-
 =head2 Template Files and Blocks
 
-=over 4
-
-=item INCLUDE_PATH
+=head3 INCLUDE_PATH
 
 One or more directories to search for templates.
 
-=item DELIMITER
+=head3 DELIMITER
 
-Delimiter for separating paths in INCLUDE_PATH (default: ':').
+Delimiter for separating paths in C<INCLUDE_PATH> (default: 'C<:>').
 
-=item ABSOLUTE
+=head3 ABSOLUTE
 
-Allow absolute file names, e.g. /foo/bar.html (default: 0).
+Allow absolute file names, e.g. C</foo/bar.html> (default: 0).
 
-=item RELATIVE
+=head3 RELATIVE
 
-Allow relative filenames, e.g. ../foo/bar.html (default: 0).
+Allow relative filenames, e.g. C<../foo/bar.html> (default: 0).
 
-=item DEFAULT
+=head3 DEFAULT
 
 Default template to use when another not found.
 
-=item BLOCKS
+=head3 BLOCKS
 
 Hash array pre-defining template blocks.
 
-=item AUTO_RESET
+=head3 AUTO_RESET
 
-Enabled by default causing BLOCK definitions to be reset each time a 
-template is processed.  Disable to allow BLOCK definitions to persist.
+Enabled by default causing C<BLOCK> definitions to be reset each time a 
+template is processed.  Disable to allow C<BLOCK> definitions to persist.
 
-=item RECURSION
+=head3 RECURSION
 
 Flag to permit recursion into templates (default: 0).
 
-=back
-
 =head2 Template Variables
 
-=over 4
-
-=item VARIABLES, PRE_DEFINE
+=head3 VARIABLES
 
 Hash array of variables and values to pre-define in the stash.
 
-=back
-
 =head2 Runtime Processing Options
 
-=over 4
+=head3 EVAL_PERL
 
-=item EVAL_PERL
+Flag to indicate if C<PERL>/C<RAWPERL> blocks should be processed (default: 0).
 
-Flag to indicate if PERL/RAWPERL blocks should be processed (default: 0).
-
-=item PRE_PROCESS, POST_PROCESS
+=head3 PRE_PROCESS, POST_PROCESS
 
 Name of template(s) to process before/after main template.
 
-=item PROCESS
+=head3 PROCESS
 
 Name of template(s) to process instead of main template.
 
-=item ERROR
+=head3 ERROR
 
 Name of error template or reference to hash array mapping error types to
 templates.
 
-=item  OUTPUT
+=head3 OUTPUT
 
 Default output location or handler.
 
-=item  OUTPUT_PATH
+=head3 OUTPUT_PATH
 
 Directory into which output files can be written.
 
-=item DEBUG
+=head3 DEBUG
 
 Enable debugging messages.
 
-=back
-
 =head2 Caching and Compiling Options
 
-=over 4
-
-=item CACHE_SIZE
+=head3 CACHE_SIZE
 
 Maximum number of compiled templates to cache in memory (default:
 undef - cache all)
 
-=item COMPILE_EXT
+=head3 COMPILE_EXT
 
 Filename extension for compiled template files (default: undef - don't
 compile).
 
-=item COMPILE_DIR
+=head3 COMPILE_DIR
 
 Root of directory in which compiled template files should be written
 (default: undef - don't compile).
 
-=back
-
 =head2 Plugins and Filters
 
-=over 4
-
-=item PLUGINS
+=head3 PLUGINS
 
 Reference to a hash array mapping plugin names to Perl packages.
 
-=item PLUGIN_BASE
+=head3 PLUGIN_BASE
 
 One or more base classes under which plugins may be found.
 
-=item LOAD_PERL
+=head3 LOAD_PERL
 
 Flag to indicate regular Perl modules should be loaded if a named plugin 
 can't be found  (default: 0).
 
-=item FILTERS
+=head3 FILTERS
 
 Hash array mapping filter names to filter subroutines or factories.
 
-=back
+=head2 Customisation and Extension
 
-=head2 Compatibility, Customisation and Extension
-
-=over 4
-
-=item V1DOLLAR
-
-Backwards compatibility flag enabling version 1.* handling (i.e. ignore it) 
-of leading '$' on variables (default: 0 - '$' indicates interpolation).
-
-=item LOAD_TEMPLATES
+=head3 LOAD_TEMPLATES
 
 List of template providers.
 
-=item LOAD_PLUGINS
+=head3 LOAD_PLUGINS
 
 List of plugin providers.
 
-=item LOAD_FILTERS
+=head3 LOAD_FILTERS
 
 List of filter providers.
 
-=item TOLERANT
+=head3 TOLERANT
 
 Set providers to tolerate errors as declinations (default: 0).
 
-=item SERVICE
+=head3 SERVICE
 
-Reference to a custom service object (default: Template::Service).
+Reference to a custom service object (default: L<Template::Service>).
 
-=item CONTEXT
+=head3 CONTEXT
 
-Reference to a custom context object (default: Template::Context).
+Reference to a custom context object (default: L<Template::Context>).
 
-=item STASH
+=head3 STASH
 
-Reference to a custom stash object (default: Template::Stash).
+Reference to a custom stash object (default: L<Template::Stash>).
 
-=item PARSER
+=head3 PARSER
 
-Reference to a custom parser object (default: Template::Parser).
+Reference to a custom parser object (default: L<Template::Parser>).
 
-=item GRAMMAR
+=head3 GRAMMAR
 
-Reference to a custom grammar object (default: Template::Grammar).
-
-=back
+Reference to a custom grammar object (default: L<Template::Grammar>).
 
 =head1 DIRECTIVE SUMMARY
 
 The following list gives a short summary of each Template Toolkit directive.
 See L<Template::Manual::Directives> for full details.
 
-=over 4
-
-=item GET
+=head2 GET
 
 Evaluate and print a variable or value.
 
     [%   GET variable %]    # 'GET' keyword is optional
-
     [%       variable %]
     [%       hash.key %]
     [%         list.n %]
@@ -708,100 +654,111 @@ Evaluate and print a variable or value.
     [% obj.meth(args) %]
     [%  "value: $var" %]
 
-=item CALL
+=head2 CALL
 
-As per GET but without printing result (e.g. call code)
+As per L<GET> but without printing result (e.g. call code)
 
     [%  CALL variable %]
 
-=item SET
+=head2 SET
 
 Assign a values to variables.
 
     [% SET variable = value %]    # 'SET' also optional
-
     [%     variable = other_variable
-    	   variable = 'literal text @ $100'
-    	   variable = "interpolated text: $var"
-    	   list     = [ val, val, val, val, ... ]
-    	   list     = [ val..val ]
-    	   hash     = { var => val, var => val, ... }
+           variable = 'literal text @ $100'
+           variable = "interpolated text: $var"
+           list     = [ val, val, val, val, ... ]
+           list     = [ val..val ]
+           hash     = { var => val, var => val, ... }
     %]
 
-=item DEFAULT
+=head2 DEFAULT
 
-Like SET above, but variables are only set if currently unset (i.e. have no
+Like L<SET>, but variables are only set if currently unset (i.e. have no
 true value).
 
     [% DEFAULT variable = value %]
 
-=item INSERT
+=head2 INSERT
 
 Insert a file without any processing performed on the contents.
 
     [% INSERT legalese.txt %]
 
-=item INCLUDE
+=head2 PROCESS
 
-Process another template file or block and include the output.  Variables
-are localised.
-
-    [% INCLUDE template %]
-    [% INCLUDE template  var = val, ... %]
-
-=item PROCESS
-
-As INCLUDE above, but without localising variables.
+Process another template file or block and insert the generated output.
+Any template L<BLOCK>s or variables defined or updated in the C<PROCESS>ed
+template will thereafter be defined in the calling template.
 
     [% PROCESS template %]
     [% PROCESS template  var = val, ... %]
 
-=item WRAPPER
+=head2 INCLUDE
 
-Process the enclosed block WRAPPER ... END block then INCLUDE the 
-named template, passing the block output in the 'content' variable.
+Similar to C<PROCESS>, but using a local copy of the current variables.
+Any template C<BLOCK>s or variables defined in the C<INCLUDE>d template
+remain local to it.
 
-    [% WRAPPER template %]
-       content...
+    [% INCLUDE template %]
+    [% INCLUDE template  var = val, ... %]
+
+=head2 WRAPPER
+
+The content between the C<WRAPPER> and correspondng C<END> directives is first
+evaluated, with the output generated being stored in the C<content> variable.
+The named template is then process as per C<INCLUDE>.
+
+    [% WRAPPER layout %]
+       Some template markup [% blah %]...
     [% END %]
 
-=item BLOCK
+A simple F<layout> template might look something like this:
 
-Define a named template block for subsequent INCLUDE, PROCESS, etc., 
+    Your header here...
+    [% content %]
+    Your footer here...
 
-    [% BLOCK template %]
-       content
+=head2 BLOCK
+
+Define a named template block for L<INCLUDE>, L<PROCESS> and L<WRAPPER>
+to use.
+
+    [% BLOCK hello %]
+       Hello World
+    [% END %]
+    
+    [% INCLUDE hello %]
+
+=head2 FOREACH
+
+Repeat the enclosed C<FOREACH> ... C<END> block for each value in the list.
+
+    [% FOREACH variable IN [ val, val, val ] %]    # either
+    [% FOREACH variable IN list %]                 # or
+       The variable is set to [% variable %]
     [% END %]
 
-=item FOREACH
+=head2 WHILE
 
-Repeat the enclosed FOREACH ... END block for each value in the list.
-
-    [% FOREACH variable = [ val, val, val ] %]	  # either
-    [% FOREACH variable = list %]                 # or
-    [% FOREACH list %]                            # or 
-       content...
-       [% variable %]
-    [% END %]
-
-=item WHILE
-
-Enclosed WHILE ... END block is processed while condition is true.
+The block enclosed between C<WHILE> and C<END> block is processed while 
+the specified condition is true.
 
     [% WHILE condition %]
        content
     [% END %]
 
-=item IF / UNLESS / ELSIF / ELSE
+=head2 IF / UNLESS / ELSIF / ELSE
 
-Enclosed block is processed if the condition is true / false.
+The enclosed block is processed if the condition is true / false.
 
     [% IF condition %]
        content
     [% ELSIF condition %]
-	 content
+     content
     [% ELSE %]
-	 content
+     content
     [% END %]
 
     [% UNLESS condition %]
@@ -810,20 +767,20 @@ Enclosed block is processed if the condition is true / false.
        content
     [% END %]
 
-=item SWITCH / CASE
+=head2 SWITCH / CASE
 
 Multi-way switch/case statement.
 
     [% SWITCH variable %]
-    [% CASE val1 %]
-       content
-    [% CASE [ val2, val3 ] %]
-       content
-    [% CASE %]         # or [% CASE DEFAULT %]
-       content
+    [%   CASE val1 %]
+           content
+    [%   CASE [ val2, val3 ] %]
+           content
+    [%   CASE %]         # or [% CASE DEFAULT %]
+           content
     [% END %]
 
-=item MACRO
+=head2 MACRO
 
 Define a named macro.
 
@@ -833,37 +790,38 @@ Define a named macro.
     [% name %]
     [% name(val1, val2) %]
 
-=item FILTER
+=head2 FILTER
 
-Process enclosed FILTER ... END block then pipe through a filter.
+Process enclosed C<FILTER> ... C<END> block then pipe through a filter.
 
-    [% FILTER name %]			    # either
-    [% FILTER name( params ) %]		    # or
-    [% FILTER alias = name( params ) %]	    # or
+    [% FILTER name %]                       # either
+    [% FILTER name( params ) %]             # or
+    [% FILTER alias = name( params ) %]     # or
        content
     [% END %]
 
-=item USE
+=head2 USE
 
-Load a "plugin" module, or any regular Perl module if LOAD_PERL option is
-set.
+Load a plugin module (see C<Template::<Manual::Plugins>), or any regular Perl
+module when the C<LOAD_PERL> option is set.
 
-    [% USE name %]			    # either
-    [% USE name( params ) %]		    # or
-    [% USE var = name( params ) %]	    # or
+    [% USE name %]                      # either
+    [% USE name( params ) %]            # or
+    [% USE var = name( params ) %]      # or
     ...
     [% name.method %]
     [% var.method %]
 
-=item PERL / RAWPERL
+=head2 PERL / RAWPERL
 
-Evaluate enclosed blocks as Perl code (requires EVAL_PERL option to be set).
+Evaluate enclosed blocks as Perl code (requires the C<EVAL_PERL> option to be
+set).
 
     [% PERL %]
-	 # perl code goes here
-	 $stash->set('foo', 10);
-	 print "set 'foo' to ", $stash->get('foo'), "\n";
-	 print $context->include('footer', { var => $val });
+     # perl code goes here
+     $stash->set('foo', 10);
+     print "set 'foo' to ", $stash->get('foo'), "\n";
+     print $context->include('footer', { var => $val });
     [% END %]
 
     [% RAWPERL %]
@@ -871,54 +829,54 @@ Evaluate enclosed blocks as Perl code (requires EVAL_PERL option to be set).
        $output .= 'some output';
     [% END %]
 
-=item TRY / THROW / CATCH / FINAL
+=head2 TRY / THROW / CATCH / FINAL
 
 Exception handling.
 
     [% TRY %]
-	 content
+     content
        [% THROW type info %]
     [% CATCH type %]
-	 catch content
+     catch content
        [% error.type %] [% error.info %]
-    [% CATCH %]	# or [% CATCH DEFAULT %]
-	 content
+    [% CATCH %] # or [% CATCH DEFAULT %]
+     content
     [% FINAL %]
        this block is always processed
     [% END %]
 
-=item NEXT
+=head2 NEXT
 
-Jump straight to the next item in a FOREACH/WHILE loop.
+Jump straight to the next item in a C<FOREACH> or C<WHILE> loop.
 
     [% NEXT %]
 
-=item LAST
+=head2 LAST
 
-Break out of FOREACH/WHILE loop.
+Break out of C<FOREACH> or C<WHILE> loop.
 
     [% LAST %]
 
-=item RETURN
+=head2 RETURN
 
 Stop processing current template and return to including templates.
 
     [% RETURN %]
 
-=item STOP
+=head2 STOP
 
 Stop processing all templates and return to caller.
 
     [% STOP %]
 
-=item TAGS
+=head2 TAGS
 
-Define new tag style or characters (default: [% %]).
+Define new tag style or characters (default: C<[%> C<%]>).
 
     [% TAGS html %]
     [% TAGS <!-- --> %]
 
-=item COMMENTS
+=head2 COMMENTS
 
 Ignored and deleted.
 
@@ -930,31 +888,21 @@ Ignored and deleted.
         tag comments out the entire directive
     %]
 
-=back
-
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
-
-L<http://wardley.org/|http://wardley.org/>
-
-
-
+Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 =head1 VERSION
 
-Template Toolkit version 2.18, released on 09 February 2007.
+Template Toolkit version 2.20, released August 2008.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
-
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-
-
 =cut
 
 # Local Variables:
