@@ -10,12 +10,11 @@
 #   Andy Wardley <abw@wardley.org>.
 #
 # COPYRIGHT
+#   Copyright (C) 2000-2007 Michael Stevens, Andy Wardley.
+#
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Directory.pm,v 2.70 2006/05/30 17:01:34 abw Exp $
-#
 #============================================================================
 
 package Template::Plugin::Directory;
@@ -41,7 +40,7 @@ sub new {
     my ($class, $context, $path) = @_;
 
     return $class->throw('no directory specified')
-	unless defined $path and length $path;
+        unless defined $path and length $path;
 
     my $self = $class->SUPER::new($context, $path, $config);
     my ($dir, @files, $name, $item, $abs, $rel, $check);
@@ -54,7 +53,7 @@ sub new {
     return $self if $config->{ nostat } || $config->{ noscan };
 
     $self->throw("$path: not a directory")
-	unless $self->{ isdir };
+        unless $self->{ isdir };
 
     $self->scan($config);
 
@@ -83,26 +82,26 @@ sub scan {
 
     @files = readdir DH;
     closedir(DH) 
-	or return $self->throw("$dir close: $!");
+        or return $self->throw("$dir close: $!");
 
     my ($path, $files, $dirs, $list) = @$self{ qw( path files dirs list ) };
     @$files = @$dirs = @$list = ();
 
     foreach $name (sort @files) {
-	next if $name =~ /^\./;
-	$abs = File::Spec->catfile($dir, $name);
-	$rel = File::Spec->catfile($path, $name);
+        next if $name =~ /^\./;
+        $abs = File::Spec->catfile($dir, $name);
+        $rel = File::Spec->catfile($path, $name);
 
-	if (-d $abs) {
-	    $item = Template::Plugin::Directory->new(undef, $rel, $config);
-	    push(@$dirs, $item);
-	}
-	else {
-	    $item = Template::Plugin::File->new(undef, $rel, $config);
-	    push(@$files, $item);
-	}
-	push(@$list, $item);
-	$self->{ _dir }->{ $name } = $item;
+        if (-d $abs) {
+            $item = Template::Plugin::Directory->new(undef, $rel, $config);
+            push(@$dirs, $item);
+        }
+        else {
+            $item = Template::Plugin::File->new(undef, $rel, $config);
+            push(@$files, $item);
+        }
+        push(@$list, $item);
+        $self->{ _dir }->{ $name } = $item;
     }
 
     return '';
@@ -144,7 +143,7 @@ sub content {
     return $self->{ list } unless $view;
     my $output = '';
     foreach my $file (@{ $self->{ list } }) {
-	$output .= $file->present($view);
+        $output .= $file->present($view);
     }
     return $output;
 }
@@ -161,20 +160,10 @@ sub throw {
     die (Template::Exception->new('Directory', $error));
 }
 
+1;
+
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Plugin::Directory - Plugin for generating directory listings
@@ -182,48 +171,48 @@ Template::Plugin::Directory - Plugin for generating directory listings
 =head1 SYNOPSIS
 
     [% USE dir = Directory(dirpath) %]
-
+    
     # files returns list of regular files
     [% FOREACH file = dir.files %]
        [% file.name %] [% file.path %] ...
     [% END %]
-
+    
     # dirs returns list of sub-directories
     [% FOREACH subdir = dir.dirs %]
        [% subdir.name %] [% subdir.path %] ...
     [% END %]
-
+    
     # list returns both interleaved in order
     [% FOREACH item = dir.list %]
        [% IF item.isdir %]
-	  Directory: [% item.name %]
-       [% ELSE 
+          Directory: [% item.name %]
+       [% ELSE %]
           File: [% item.name %]
        [% END %]
     [% END %]
-
+    
     # define a VIEW to display dirs/files
     [% VIEW myview %]
        [% BLOCK file %]
        File: [% item.name %]
        [% END %]
-
+       
        [% BLOCK directory %]
        Directory: [% item.name %] 
        [% item.content(myview) | indent -%]
        [% END %]
     [% END %]
-
+    
     # display directory content using view
     [% myview.print(dir) %]
 
 =head1 DESCRIPTION
 
 This Template Toolkit plugin provides a simple interface to directory
-listings.  It is derived from the Template::Plugin::File module and
-uses Template::Plugin::File object instances to represent files within
+listings.  It is derived from the L<Template::Plugin::File> module and
+uses L<Template::Plugin::File> object instances to represent files within
 a directory.  Sub-directories within a directory are represented by
-further Template::Plugin::Directory instances.
+further C<Template::Plugin::Directory> instances.
 
 The constructor expects a directory name as an argument.
 
@@ -233,37 +222,35 @@ It then provides access to the files and sub-directories contained within
 the directory.
 
     # regular files (not directories)
-    [% FOREACH file = dir.files %]
+    [% FOREACH file IN dir.files %]
        [% file.name %]
     [% END %]
 
     # directories only
-    [% FOREACH file = dir.dirs %]
+    [% FOREACH file IN dir.dirs %]
        [% file.name %]
     [% END %]
 
     # files and/or directories
-    [% FOREACH file = dir.list %]
+    [% FOREACH file IN dir.list %]
        [% file.name %] ([% file.isdir ? 'directory' : 'file' %])
     [% END %]
 
-    [% USE Directory('foo/baz') %]
-
-The plugin constructor will throw a 'Directory' error if the specified
-path does not exist, is not a directory or fails to stat() (see
+The plugin constructor will throw a C<Directory> error if the specified
+path does not exist, is not a directory or fails to C<stat()> (see
 L<Template::Plugin::File>).  Otherwise, it will scan the directory and
-create lists named 'files' containing files, 'dirs' containing
-directories and 'list' containing both files and directories combined.
-The 'nostat' option can be set to disable all file/directory checks
+create lists named 'C<files>' containing files, 'C<dirs>' containing
+directories and 'C<list>' containing both files and directories combined.
+The C<nostat> option can be set to disable all file/directory checks
 and directory scanning.
 
 Each file in the directory will be represented by a
-Template::Plugin::File object instance, and each directory by another
-Template::Plugin::Directory.  If the 'recurse' flag is set, then those
+L<Template::Plugin::File> object instance, and each directory by another
+C<Template::Plugin::Directory>.  If the C<recurse> flag is set, then those
 directories will contain further nested entries, and so on.  With the
-'recurse' flag unset, as it is by default, then each is just a place
+C<recurse> flag unset, as it is by default, then each is just a place
 marker for the directory and does not contain any further content
-unless its scan() method is explicitly called.  The 'isdir' flag can
+unless its C<scan()> method is explicitly called.  The C<isdir> flag can
 be tested against files and/or directories, returning true if the item
 is a directory or false if it is a regular file.
 
@@ -277,19 +264,19 @@ is a directory or false if it is a regular file.
 
 This example shows how you might walk down a directory tree, displaying 
 content as you go.  With the recurse flag disabled, as is the default, 
-we need to explicitly call the scan() method on each directory, to force
+we need to explicitly call the C<scan()> method on each directory, to force
 it to lookup files and further sub-directories contained within. 
 
     [% USE dir = Directory(dirpath) %]
     * [% dir.path %]
     [% INCLUDE showdir %]
-
+    
     [% BLOCK showdir -%]
       [% FOREACH file = dir.list -%]
         [% IF file.isdir -%]
         * [% file.name %]
           [% file.scan -%]
-	  [% INCLUDE showdir dir=file FILTER indent(4) -%]
+          [% INCLUDE showdir dir=file FILTER indent(4) -%]
         [% ELSE -%]
         - [% f.name %]
         [% END -%]
@@ -300,34 +287,34 @@ This example is adapted (with some re-formatting for clarity) from
 a test in F<t/directry.t> which produces the following output:
 
     * test/dir
-    	- file1
-    	- file2
-    	* sub_one
-    	    - bar
-    	    - foo
-    	* sub_two
-    	    - waz.html
-    	    - wiz.html
-    	- xyzfile
+        - file1
+        - file2
+        * sub_one
+            - bar
+            - foo
+        * sub_two
+            - waz.html
+            - wiz.html
+        - xyzfile
 
-The 'recurse' flag can be set (disabled by default) to cause the
+The C<recurse> flag can be set (disabled by default) to cause the
 constructor to automatically recurse down into all sub-directories,
-creating a new Template::Plugin::Directory object for each one and 
+creating a new C<Template::Plugin::Directory> object for each one and 
 filling it with any further content.  In this case there is no need
-to explicitly call the scan() method.
+to explicitly call the C<scan()> method.
 
     [% USE dir = Directory(dirpath, recurse=1) %]
        ...
-
+       
         [% IF file.isdir -%]
         * [% file.name %]
-	  [% INCLUDE showdir dir=file FILTER indent(4) -%]
+          [% INCLUDE showdir dir=file FILTER indent(4) -%]
         [% ELSE -%]
            ...
 
-From version 2.01, the Template Toolkit provides support for views.
-A view can be defined as a VIEW ... END block and should contain 
-BLOCK definitions for files ('file') and directories ('directory').
+The directory plugin also provides support for views. A view can be defined as
+a C<VIEW ... END> block and should contain C<BLOCK> definitions for files
+('C<file>') and directories ('C<directory>').
 
     [% VIEW myview %]
     [% BLOCK file %]
@@ -340,28 +327,29 @@ BLOCK definitions for files ('file') and directories ('directory').
     [% END %]
     [% END %]
 
-Then the view print() method can be called, passing the
-Directory object as an argument.
+The view C<print()> method can then be called, passing the
+C<Directory> object as an argument.
 
     [% USE dir = Directory(dirpath, recurse=1) %]
     [% myview.print(dir) %]
 
-When a directory is presented to a view, either as [% myview.print(dir) %]
-or [% dir.present(view) %], then the 'directory' BLOCK within the 'myview' 
-VIEW is processed, with the 'item' variable set to alias the Directory object.
+When a directory is presented to a view, either as C<[% myview.print(dir) %]>
+or C<[% dir.present(view) %]>, then the C<directory> C<BLOCK> within the
+C<myview> C<VIEW> is processed. The C<item> variable will be set to alias the
+C<Directory> object.
 
     [% BLOCK directory %]
        * [% item.name %]
          [% item.content(myview) FILTER indent %]
     [% END %]
 
-The directory name is first printed and the content(view) method is
-then called to present each item within the directory to the view.
-Further directories will be mapped to the 'directory' block, and files
-will be mapped to the 'file' block.
+In this example, the directory name is first printed and the content(view)
+method is then called to present each item within the directory to the view.
+Further directories will be mapped to the C<directory> block, and files will be
+mapped to the C<file> block.
 
-With the recurse option disabled, as it is by default, the 'directory'
-block should explicitly call a scan() on each directory.
+With the recurse option disabled, as it is by default, the C<directory>
+block should explicitly call a C<scan()> on each directory.
 
     [% VIEW myview %]
     [% BLOCK file %]
@@ -370,39 +358,29 @@ block should explicitly call a scan() on each directory.
     
     [% BLOCK directory %]
        * [% item.name %]
-	 [% item.scan %]
+         [% item.scan %]
          [% item.content(myview) FILTER indent %]
     [% END %]
     [% END %]
-
+    
     [% USE dir = Directory(dirpath) %]
     [% myview.print(dir) %]
 
-=head1 TODO
-
-Might be nice to be able to specify accept/ignore options to catch
-a subset of files.
-
 =head1 AUTHORS
 
-Michael Stevens E<lt>michael@etla.orgE<gt> wrote the original Directory plugin
-on which this is based.  Andy Wardley E<lt>abw@wardley.orgE<gt> split it into 
-separate File and Directory plugins, added some extra code and documentation
-for VIEW support, and made a few other minor tweaks.
-
-=head1 VERSION
-
-2.7, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
-
-
+Michael Stevens wrote the original Directory plugin on which this is based.
+Andy Wardley split it into separate L<File|Template::Plugin::File> and
+L<Directory|Template::Plugin::Directory> plugins, added some extra code and
+documentation for C<VIEW> support, and made a few other minor tweaks.
 
 =head1 COPYRIGHT
 
+Copyright (C) 2000-2007 Michael Stevens, Andy Wardley.
+
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin|Template::Plugin>, L<Template::Plugin::File|Template::Plugin::File>, L<Template::View|Template::View>
+L<Template::Plugin>, L<Template::Plugin::File>, L<Template::View>
 
