@@ -15,7 +15,7 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: VMethods.pm,v 1.1 2006/05/30 16:58:36 abw Exp $
+#   $Id: VMethods.pm 1130 2008-08-06 12:07:52Z abw $
 #
 #============================================================================
 
@@ -507,7 +507,9 @@ sub list_merge {
 sub list_slice {
     my ($list, $from, $to) = @_;
     $from ||= 0;
-    $to = $#$list unless defined $to;
+    $to    = $#$list unless defined $to;
+    $from += @$list if $from < 0;
+    $to   += @$list if $to   < 0;
     return [ @$list[$from..$to] ];
 }
 
@@ -535,6 +537,34 @@ sub list_splice {
 
 __END__
 
+=head1 NAME
+
+Template::VMethods - Virtual methods for variables
+
+=head1 DESCRIPTION
+
+The C<Template::VMethods> module implements the virtual methods
+that can be applied to variables.
+
+Please see L<Template::Manual::VMethods> for further information.
+
+=head1 AUTHOR
+
+Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
+
+=head1 COPYRIGHT
+
+Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<Template::Stash>, L<Template::Manual::VMethods>
+
+=cut
+
 # Local Variables:
 # mode: perl
 # perl-indent-level: 4
